==> ejc-accplat-impl-3.0.0-20231225.023258-50-sources.jar: com/ejianc/business/kingdee/test/InvokeTest1.java <==
package com.ejianc.business.kingdee.test;

import com.ejianc.business.kingdee.base.vo.save.*;
import com.ejianc.business.voucher.utils.DataConvertUtil;

import java.math.BigDecimal;
import java.util.Arrays;

/**
 * @description: TODO
 * @author songlx
 * @date 2023/12/12
 * @version 1.0
 */
public class InvokeTest1 {

    // http://123.234.41.174:8090/k3cloud/html5/index.aspx
    //账号 ：徐慧/666666  选世纪阳光测试账套
    public static void main(String[] args) throws Exception {
        InvokeHelper.POST_K3CloudURL = "http://123.234.41.174:8090/K3Cloud/";
        String dbId = "6576a9828d11ae";
        String uid = "徐慧";
        String pwd = "666666";
        int lang = 2052;

        if (InvokeHelper.Login(dbId, uid, pwd, lang)) {

            String sFormId = "GL_VOUCHER";

            Object projectName = "测试项目";
            Object settleTaxMny = new BigDecimal("299");


            KingDeeVoucherApiSaveVO kingDeeVoucherApiSaveVO = new KingDeeVoucherApiSaveVO<Model>();
            Model model = new Model();

            // 账簿
            FAccountBookID fAccountBookID = new FAccountBookID();
            fAccountBookID.setFNumber("S01");
            model.setFAccountBookID(fAccountBookID);
            // 日期
            model.setFDate("2023-12-19");
            // FBUSDATE 业务日期
            model.setFBUSDATE("Z");
            // FYEAR 会计年度

            // FPERIOD 期间

            // FVOUCHERGROUPID 凭证字
            FVOUCHERGROUPID fvouchergroupid = new FVOUCHERGROUPID();
            fvouchergroupid.setFNumber("PRE001");
            model.setFVOUCHERGROUPID(fvouchergroupid);
            // FDocumentStatus 审核状态
            model.setFDocumentStatus("Z");


            FEntity fEntity1 = new FEntity();
            // 摘要
            fEntity1.setFEXPLANATION(projectName + "_业务测试");
            // FACCOUNTID 科目编码
            FACCOUNTID faccountid = new FACCOUNTID();
            faccountid.setFNumber("2202.02");
            fEntity1.setFACCOUNTID(faccountid);

            // FAMOUNTFOR 原币金额
            fEntity1.setFAMOUNTFOR(settleTaxMny);

            // FAMOUNTFOR 原币金额
            fEntity1.setFAMOUNTFOR(settleTaxMny);
            // FDEBIT 借方金额
            fEntity1.setFDEBIT(settleTaxMny);


            // FCURRENCYID 币别
            FCURRENCYID fcurrencyid = new FCURRENCYID();
            fcurrencyid.setFNumber("PRE001");
            fEntity1.setFCURRENCYID(fcurrencyid);

            // FEXCHANGERATETYPE 汇率类型
            FEXCHANGERATETYPE fexchangeratetype = new FEXCHANGERATETYPE();
            fexchangeratetype.setFNumber("HLTX01_SYS");
            fEntity1.setFEXCHANGERATETYPE(fexchangeratetype);

            // FEXCHANGERATE 汇率
            //fEntity1.setFEXCHANGERATE("1");

            //核算对象
            FDetailID fDetailID = new FDetailID();
            FDETAILID__FFLEX4 fdetailid__fflex4 = new FDETAILID__FFLEX4();
            fdetailid__fflex4.setFNumber("1.001");
            fDetailID.setFDETAILID__FFLEX4(fdetailid__fflex4);
            fEntity1.setFDetailID(fDetailID);


            FEntity fEntity2 = new FEntity();
            // 摘要
            fEntity2.setFEXPLANATION(projectName + "_业务测试");
            // FACCOUNTID 科目编码
            FACCOUNTID faccountid2 = new FACCOUNTID();
            faccountid2.setFNumber("1001.01");
            fEntity2.setFACCOUNTID(faccountid2);
            // FAMOUNTFOR 原币金额
            fEntity2.setFAMOUNTFOR(settleTaxMny);

            // FCREDIT 贷方金额
            fEntity2.setFCREDIT(settleTaxMny);

            // FCURRENCYID 币别
            fEntity2.setFCURRENCYID(fcurrencyid);

            // FEXCHANGERATETYPE 汇率类型
            fEntity2.setFEXCHANGERATETYPE(fexchangeratetype);
            // FEXCHANGERATE 汇率
            //fEntity2.setFEXCHANGERATE("1");

            model.setFEntity(Arrays.asList(fEntity1, fEntity2));
            kingDeeVoucherApiSaveVO.setModel(model);
            System.out.println("data:" + DataConvertUtil.objToString(kingDeeVoucherApiSaveVO));
            InvokeHelper.Save(sFormId, DataConvertUtil.objToString(kingDeeVoucherApiSaveVO));

            System.out.println("hola success");
        }
    }
}

==> ejc-accplat-impl-3.0.0-20240124.025510-141-sources.jar: com/ejianc/business/kingdee/test/InvokeTest1.java <==
package com.ejianc.business.kingdee.test;

import com.ejianc.business.kingdee.base.vo.save.*;
import com.ejianc.business.voucher.utils.DataConvertUtil;

import java.math.BigDecimal;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

/**
 * @description: TODO
 * @author songlx
 * @date 2023/12/12
 * @version 1.0
 */
public class InvokeTest1 {

    // http://123.234.41.174:8090/k3cloud/html5/index.aspx
    //账号 ：徐慧/666666  选世纪阳光测试账套
    public static void main(String[] args) throws Exception {
        InvokeHelper.POST_K3CloudURL = "http://123.234.41.174:8090/K3Cloud/";
        String dbId = "6576a9828d11ae";
        String uid = "徐慧";
        String pwd = "666666";
        int lang = 2052;

        if (InvokeHelper.Login(dbId, uid, pwd, lang)) {

            String sFormId = "GL_VOUCHER";

            Object projectName = "测试项目";
            Object settleTaxMny = new BigDecimal("299");


            KingDeeVoucherApiSaveVO kingDeeVoucherApiSaveVO = new KingDeeVoucherApiSaveVO<Model>();
            Model model = new Model();

            // 账簿
            FAccountBookID fAccountBookID = new FAccountBookID();
            fAccountBookID.setFNumber("S01");
            model.setFAccountBookID(fAccountBookID);
            // 日期
            model.setFDate("2023-12-27");
            // FBUSDATE 业务日期
            model.setFBUSDATE("Z");
            // FYEAR 会计年度

            // FPERIOD 期间

            // FVOUCHERGROUPID 凭证字
            FVOUCHERGROUPID fvouchergroupid = new FVOUCHERGROUPID();
            fvouchergroupid.setFNumber("PRE001");
            model.setFVOUCHERGROUPID(fvouchergroupid);
            // FDocumentStatus 审核状态
            model.setFDocumentStatus("Z");


            FEntity fEntity1 = new FEntity();
            // 摘要
            fEntity1.setFEXPLANATION(projectName + "_业务测试");
            // FACCOUNTID 科目编码
            FACCOUNTID faccountid = new FACCOUNTID();
            faccountid.setFNumber("6601");
            fEntity1.setFACCOUNTID(faccountid);

            // FAMOUNTFOR 原币金额
            fEntity1.setFAMOUNTFOR(settleTaxMny);

            // FAMOUNTFOR 原币金额
            fEntity1.setFAMOUNTFOR(settleTaxMny);
            // FDEBIT 借方金额
            fEntity1.setFDEBIT(settleTaxMny);


            // FCURRENCYID 币别
            FCURRENCYID fcurrencyid = new FCURRENCYID();
            fcurrencyid.setFNumber("PRE001");
            fEntity1.setFCURRENCYID(fcurrencyid);

            // FEXCHANGERATETYPE 汇率类型
            FEXCHANGERATETYPE fexchangeratetype = new FEXCHANGERATETYPE();
            fexchangeratetype.setFNumber("HLTX01_SYS");
            fEntity1.setFEXCHANGERATETYPE(fexchangeratetype);

            // FEXCHANGERATE 汇率
            //fEntity1.setFEXCHANGERATE("1");

            //核算对象
            Map _FDetailID = new HashMap<String, FDetailID>();
            FDetailID _FDETAILID__FFLEX = new FDetailID();
            _FDETAILID__FFLEX.setFNumber("1.001");
            _FDetailID.put("FDETAILID__FFLEX4", _FDETAILID__FFLEX);
            fEntity1.setFDetailID(_FDetailID);


            FEntity fEntity2 = new FEntity();
            // 摘要
            fEntity2.setFEXPLANATION(projectName + "_业务测试");
            // FACCOUNTID 科目编码
            FACCOUNTID faccountid2 = new FACCOUNTID();
            faccountid2.setFNumber("1001.01");
            fEntity2.setFACCOUNTID(faccountid2);
            // FAMOUNTFOR 原币金额
            fEntity2.setFAMOUNTFOR(settleTaxMny);

            // FCREDIT 贷方金额
            fEntity2.setFCREDIT(settleTaxMny);

            // FCURRENCYID 币别
            fEntity2.setFCURRENCYID(fcurrencyid);

            // FEXCHANGERATETYPE 汇率类型
            fEntity2.setFEXCHANGERATETYPE(fexchangeratetype);
            // FEXCHANGERATE 汇率
            //fEntity2.setFEXCHANGERATE("1");

            model.setFEntity(Arrays.asList(fEntity1, fEntity2));
            kingDeeVoucherApiSaveVO.setModel(model);
            System.out.println("data:" + DataConvertUtil.objToString(kingDeeVoucherApiSaveVO));
            InvokeHelper.Save(sFormId, DataConvertUtil.objToString(kingDeeVoucherApiSaveVO));

            System.out.println("hola success");
        }
    }
}
